@@ -41,7 +41,7 @@ class Exercise(BASE,Template):
     __tablename__="Exercise"
     exid=Column(Integer,primary_key=True)
     Name=Column(String,default=f'Generic Exercise Name [{nanoid.generate()}]')
-    Note=Column(String,default='')
+    Note=Column(String,default=json.dumps({'completed':0}))
     Reps=Column(Integer,default=1) # 8 reps of 30 repcounts NAME
     RepCount=Column(Integer,default=30) #30 times rep
     CurrentRep=Column(Integer,default=0)
@@ -255,10 +255,6 @@ class ExerciseTracker:
                 'default':'',
                 'type':'string',
                 },
-            'Note':{
-                'default':'',
-                'type':'string',
-                },
             }
             routine=FormBuilder(data=data_r)
             while True:
@@ -280,13 +276,37 @@ class ExerciseTracker:
                         nt=gethpv(routine)
                         #print(nt)
                         nt+=1
-                        rts=Routine(Name=routine.get("Name"),Note=routine.get("Note"),exid=i.exid,precedence=nt,doe=doe,dtoe=dtoe,toe=toe)
+                        rts=Routine(Name=routine.get("Name"),Note=json.dumps({'completed':0}),exid=i.exid,precedence=nt,doe=doe,dtoe=dtoe,toe=toe)
                         session.add(rts)
                         session.commit()
+                        session.refresh(rts)
+                        '''
+                        self.clearRoutine(rts)
                         #print(gethpv(routine))
+                        rout[num].Note=json.dumps({'completed':0})
+                        session.commit()
+                        session.flush()
+                        session.refresh(rout[num])
+                        '''
                     else:
                         pass
+    def reset_routine(self):
+        if not shield(self,mode='ExerciseTracker',fieldname='Routine',action_text='Delete All Routines'):
+            with Session(ENGINE) as session:
+                session.query(Routine).delete()
+                session.commit()
+                print(f"Remaining Routines: {session.query(Routine).count()}")
 
+    def reset_exercises(self):
+        if not shield(self,mode='ExerciseTracker',fieldname='Exercise',action_text='Delete All Exercises'):
+            with Session(ENGINE) as session:
+                session.query(Exercise).delete()
+                session.commit()
+                print(f"Remaining Exercises: {session.query(Exercise).count()}")
+
+    def reset_er(self):
+        self.reset_exercises()
+        self.reset_routine()
 
     def Add2Routine(self):
         with Session(ENGINE) as session:
@@ -493,7 +513,7 @@ class ExerciseTracker:
                 if returnable:
                     lite=[]
                 for num,r in enumerate(results):
-                    msg=f"{Fore.light_yellow}{num}/{Fore.light_red}{ct}{Style.reset}{Fore.light_steel_blue} -> {r.Name}{Style.reset}"
+                    msg=f"{Fore.light_yellow}{num}/{Fore.light_red}{ct}{Style.reset}{Fore.light_steel_blue} -> {r.Name} (roid={r.roid}){Style.reset}"
                     print(msg)
                     if returnable:
                         lite.append(r.Name)
@@ -511,36 +531,46 @@ class ExerciseTracker:
             else:
                 if returnable:
                     lite=[]
+                hr=None
                 for num,r in enumerate(results):
+
                     ex=session.query(Exercise).filter(Exercise.exid==r.exid).first()
                     if ex:
                         name,note,exid=ex.Name,ex.Note,ex.exid
                     else:
                         name,note,exid="NotFound?","NotFound?","NotFound?"
-                    msg=f"{Fore.light_yellow}{num}/{Fore.light_red}{ct}{Style.reset}{Fore.light_steel_blue} -> {r.Name} Exercise(Name='{name}',Note='{note}',exid='{exid}'){Style.reset}"
+                    msg=f"{Fore.light_yellow}{num}/{Fore.light_red}{ct}{Style.reset}{Fore.light_steel_blue} -> {r.Name}  (roid={r.roid},exid={exid}) Exercise(Name='{name}',Note='{note}',exid='{exid}'){Style.reset}"
                     print(msg)
                     if returnable:
                         lite.append(r.Name)
+                    if hr != r.Name and num != 0:
+                        if hr != None:
+                            print(f"{'*'*os.get_terminal_size().columns}")
+                        hr=r.Name
                 if returnable:
                     return lite
 
     def useRoutine(self,reset_only=False,reset_note=False):
         try:
+            
             logMe=Prompt.__init2__(None,func=FormBuilderMkText,ptext="Log a comment in HealthLog(hl[default=True/Yes])?",helpText="yes or no/boolean",data="boolean")
             if logMe is None:
                 return
             elif logMe in ['d',]:
                 logMe=True
-
+            
             start=datetime.now()
             rs=self.viewRoutine(returnable=True)
             if rs == None:
                 return
+
+           
             whichList=Prompt.__init2__(None,func=FormBuilderMkText,ptext="Which Routine would you like to use?",helpText="first number of a line",data="list")
             if whichList in ['d']:
                 whichList=[]
             elif whichList in [None,]:
                 return
+            
             for which in whichList:
                 try:
                     which=int(which)
@@ -578,10 +608,10 @@ class ExerciseTracker:
                         
                         if reset_note:
                             for num, i in enumerate(rout):
-                                    rout[num].Note=json.dumps({'completed':0})
-                                    session.commit()
-                                    session.flush()
-                                    session.refresh(rout[num])
+                                rout[num].Note=json.dumps({'completed':0})
+                                session.commit()
+                                session.flush()
+                                session.refresh(rout[num])
                         if reset_only:
                             #resume
                             if logMe:
@@ -711,20 +741,27 @@ class ExerciseTracker:
         h=f'{Prompt.header.format(Fore=Fore,mode=mode,fieldname=fieldname,Style=Style)}'
         header='{Fore.grey_70}[{Fore.light_steel_blue}{mode}{Fore.medium_violet_red}@{Fore.light_green}{fieldname}{Fore.grey_70}]{Style.reset}{Fore.light_yellow} '
 
-        helpText=f'''
-        ne,NewExercise - create a new exercise
-        re,RemoveExercise - delete an exercise
-        se,SearchExercise - search for an exercise from it's Note,Name, or ID
-        ee,EditExercise - edit an exercise
-        nr,NewRoutine - a new routine of exercises
-        vr,ViewRoutines - show available routines
-        vrl,ViewRoutines - show available routines and their exercises as a list
-        a2r,add2routine - add an exercise to a routine specified by RID
-        ur,UseRoutine - use a set routine
-        rr,RemoveRoutine - delete a routine
-        cr,ClearRoutine - reset routine CurrentRep
-        su,summarize,Summarize - show the contents of a specified Routine
-        '''
+        helpText=f'''{Fore.light_green}Exercises{Fore.grey_70}
+    ** ne,NewExercise - create a new exercise
+    ** re,RemoveExercise - delete an exercise
+    ** se,SearchExercise - search for an exercise from it's Note,Name, or ID
+    ** ee,EditExercise - edit an exercise
+{Fore.dark_goldenrod}Routines{Fore.grey_70}
+    ** nr,NewRoutine - a new routine of exercises
+    ** vr,ViewRoutines - show available routines
+    ** vrl,ViewRoutines - show available routines and their exercises as a list
+    ** a2r,add2routine - add an exercise to a routine specified by RID
+    ** ur,UseRoutine - use a set routine
+    ** rr,RemoveRoutine - delete a routine
+    ** cr,ClearRoutine - reset routine CurrentRep
+    ** su,summarize,Summarize - show the contents of a specified Routine
+{Fore.orange_red_1}DANGER{Fore.grey_70}
+    ** rst rtn,reset routine,reset-routine - delete all routines {Fore.light_red}ONLY{Fore.grey_70}
+    ** rst ex,reset exercises,reset-exercises - delete all exercises {Fore.light_red}ONLY{Fore.grey_70}
+    ** rst a,reset all,reset-all - delete {Fore.dark_goldenrod}<{Fore.orange_red_1}<<{Fore.medium_violet_red}<<{Fore.light_cyan}Everything{Fore.medium_violet_red}>>{Fore.orange_red_1}>>{Fore.dark_goldenrod}> {Fore.cyan} in the ExerciseTracker!
+{Fore.light_salmon_1}WARNING{Fore.grey_70}
+    ignore '**' ; this is not part of the cmd; it's just a bullet point representation.
+{Style.reset}'''
         while True:
             doWhat=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"{h} Do what?",helpText=helpText,data="string")
             if doWhat in [None,]:
@@ -744,7 +781,7 @@ class ExerciseTracker:
                 self.newRoutine()
             elif doWhat.lower() in ['vr','ViewRoutine'.lower()]:
                 self.viewRoutine()
-            elif doWhat.lower() in ['vlr','ViewRoutineList'.lower()]:
+            elif doWhat.lower() in ['vrl','ViewRoutineList'.lower()]:
                 self.viewRoutineList()
             elif doWhat.lower() in ['ur','UseRoutine'.lower()]:
                 self.useRoutine()
@@ -757,4 +794,10 @@ class ExerciseTracker:
             elif doWhat.lower() in "su,summarize".split(","):
                 self.summarize()
             elif doWhat.lower() in 'a2r,add2routine'.split(","):
-                self.Add2Routine()
\ No newline at end of file
+                self.Add2Routine()
+            elif doWhat.lower() in 'rst rtn,reset routine,reset-routine'.split(','):
+                self.reset_routine()
+            elif doWhat.lower() in 'rst ex,reset exercises,reset-exercises'.split(','):
+                self.reset_exercises()
+            elif doWhat.lower() in 'rst a,reset all,reset-all'.split(','):
+                self.reset_er()
\ No newline at end of file
