@@ -9,6 +9,7 @@ from datetime import timedelta
 import calendar
 from colored import Fore,Back,Style
 import itertools
+from uuid import uuid1
 
 def generate_cmds(startcmd,endCmd):
     cmd=(startcmd,endCmd)
@@ -304,13 +305,59 @@ def FormBuilderMkText(text,data,passThru=[],PassThru=True,alternative_false=None
                     print(e)
         elif data.lower() in ['datetime','datetime-','datetime~']:
             try:
-                
+                def regexSelect(ds):
+                    fmt={}
+                    fmt[str(uuid1())]=[re.compile(r"[0-1][0-9].[0-9][0-9]"),"%m#CHAR#%y"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-1][0-9].[0-9][0-9][0-9][0-9]"),"%m#CHAR#%Y"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-9].[0-9][0-9][0-9][0-9]"),"%m#CHAR#%Y"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-9].[0-9][0-9]"),"%m#CHAR#%y"]
+
+                    fmt[str(uuid1())]=[re.compile(r"[0-1][0-9].[0-9][0-9].[0-9][0-9]"),"%m#CHAR#%d#CHAR#%y"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-1][0-9].[0-9][0-9].[0-9][0-9][0-9][0-9]"),"%m#CHAR#%d#CHAR#%Y"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-9].[0-9][0-9].[0-9][0-9][0-9][0-9]"),"%m#CHAR#%d#CHAR#%Y"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-9].[0-9][0-9].[0-9][0-9]"),"%m#CHAR#%d#CHAR#%y"]
+
+                    fmt[str(uuid1())]=[re.compile(r"[0-1][0-9].[0-9][0-9].[0-9][0-9]@[0-9][0-9]:[0-9][0-9]"),"%m#CHAR#%d#CHAR#%y@%H:%M"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-1][0-9].[0-9][0-9].[0-9][0-9][0-9][0-9]@[0-9][0-9]:[0-9][0-9]"),"%m#CHAR#%d#CHAR#%Y@%H:%M"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-9].[0-9][0-9].[0-9][0-9][0-9][0-9]@[0-9][0-9]:[0-9][0-9]"),"%m#CHAR#%d#CHAR#%Y@%H:%M"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-9].[0-9][0-9].[0-9][0-9]@[0-9][0-9]:[0-9][0-9]"),"%m#CHAR#%d#CHAR#%y@%H:%M"]
+
+                    fmt[str(uuid1())]=[re.compile(r"[0-1][0-9].[0-9].[0-9][0-9]@[0-9][0-9]:[0-9][0-9]"),"%m#CHAR#%d#CHAR#%y@%H:%M"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-1][0-9].[0-9].[0-9][0-9][0-9][0-9]@[0-9][0-9]:[0-9][0-9]"),"%m#CHAR#%d#CHAR#%Y@%H:%M"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-9].[0-9].[0-9][0-9][0-9][0-9]@[0-9][0-9]:[0-9][0-9]"),"%m#CHAR#%d#CHAR#%Y@%H:%M"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-9].[0-9].[0-9][0-9]@[0-9][0-9]:[0-9][0-9]"),"%m#CHAR#%d#CHAR#%y@%H:%M"]
+
+                    fmt[str(uuid1())]=[re.compile(r"[0-1][0-9].[0-9].[0-9][0-9]@[0-9][0-9]:[0-9]"),"%m#CHAR#%d#CHAR#%y@%H:%M"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-1][0-9].[0-9].[0-9][0-9][0-9][0-9]@[0-9][0-9]:[0-9][0-9]"),"%m#CHAR#%d#CHAR#%Y@%H:%M"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-9].[0-9].[0-9][0-9][0-9][0-9]@[0-9][0-9]:[0-9][0-9]"),"%m#CHAR#%d#CHAR#%Y@%H:%M"]
+                    fmt[str(uuid1())]=[re.compile(r"[0-9].[0-9].[0-9][0-9]@[0-9][0-9]:[0-9]"),"%m#CHAR#%d#CHAR#%y@%H:%M"]
+
+                    ct=len(fmt)
+                    for num,i in enumerate(fmt):
+                        print(db.std_colorize(fmt[i],num,ct))
+
+                    for i in fmt:
+                        if fmt[i][0].findall(ds) != []:
+                            print(fmt[i][1])
+                            for char in ds:
+                                if char in string.punctuation:
+                                    try:
+                                        fmt[i][1]=fmt[i][1].replace("#CHAR#",char)
+                                        return True,datetime.strptime(ds,fmt[i][1])
+                                    except Exception as e:
+                                        print(e)
+
+                    return False,None
+
                 TODAY_IS=datetime.now()
                 z=TODAY_IS
                 if text.lower() in ['y','yes','1','t','true','+']:
                     value=TM.Tasks.TasksMode(parent=None,engine=db.ENGINE,init_only=True).DateTimePkr()
                 elif text.lower() in ['now',]:
                     return datetime.now()
+                elif regexSelect(text.lower())[0] == True:
+                    bild=regexSelect(text.lower())
+                    return bild[-1]
                 elif text.lower() in ['today',]:
                     return datetime(year=TODAY_IS.year,month=TODAY_IS.month,day=TODAY_IS.day)
                 elif text.lower() in ['tomorrow',]:
