@@ -461,6 +461,13 @@ class Expiration:
 						print(e)
 
 	def search_expo(self,returnable=False,code=None,group=True,past_due_only=False):
+		gtemp=group
+		group=Control(func=FormBuilderMkText,ptext="Group results?",helpText=f"default is {group}",data="boolean")
+		if group in [None,'NaN']:
+			return
+		elif group in ['d',]:
+			group=gtemp
+		
 		with Session(ENGINE) as session:
 			while True:
 				if code != None:
