@@ -109,6 +109,7 @@ def bare_ca(self,inList=False,protect_unassigned=True):
 						'Expiry':None,
 						'BestBy':None,
 						'AquisitionDate':None,
+						'Location':'///',
 						})
 				else:
 					result=session.query(db.Entry).filter(db.Entry.InList==True,db.Entry.Code!="UNASSIGNED_TO_NEW_ITEM").update({
@@ -138,6 +139,7 @@ def bare_ca(self,inList=False,protect_unassigned=True):
 						'Expiry':None,
 						'BestBy':None,
 						'AquisitionDate':None,
+						'Location':'///',
 						})
 			else:
 				if not protect_unassigned:
@@ -168,6 +170,7 @@ def bare_ca(self,inList=False,protect_unassigned=True):
 						'Expiry':None,
 						'BestBy':None,
 						'AquisitionDate':None,
+						'Location':'///',
 						})
 				else:
 					result=session.query(db.Entry).filter(db.Entry.Code!="UNASSIGNED_TO_NEW_ITEM").update(
@@ -197,6 +200,7 @@ def bare_ca(self,inList=False,protect_unassigned=True):
 						'Expiry':None,
 						'BestBy':None,
 						'AquisitionDate':None,
+						'Location':'///',
 						})
 			session.commit()
 			session.flush()
@@ -229,7 +233,8 @@ def bare_ca(self,inList=False,protect_unassigned=True):
 						'CHKSTND_SPLY':0,
 						'Expiry':None,
 						'BestBy':None,
-						'AquisitionDate':None,})
+						'AquisitionDate':None,
+						'Location':'///',})
 			session.commit()
 			session.flush()
 			r=query.all()
@@ -261,7 +266,8 @@ def bare_ca(self,inList=False,protect_unassigned=True):
 						'CHKSTND_SPLY':0,
 						'Expiry':None,
 						'BestBy':None,
-						'AquisitionDate':None,}
+						'AquisitionDate':None,
+						'Location':'///',}
 				)
 			session.commit()
 			session.flush()
