@@ -7,6 +7,26 @@ preloader={
 						'desc':f'find the volume of height*width*length without dimensions',
 						'exec':volume
 					},
+	f'{uuid1()}':{
+						'cmds':['federal tax withholding',],
+						'desc':f'calculate your tax withholding for federal; you will need the IRS Publication 15-T ({datetime.now().year})',
+						'exec':FederalIncomeTaxWithholding
+					},
+	f'{uuid1()}':{
+						'cmds':['va state tax withholding',],
+						'desc':f'calculate your tax withholding for va state; you will need the "Virginia/VA Employer Withholding Tables" for ({datetime.now().year})',
+						'exec':VAStateIncomeTaxWithholding
+					},
+	f'{uuid1()}':{
+						'cmds':['mpgl','mpg log','mpg logger','miles per gallon log'],
+						'desc':f'log your miles per gallon, make sure you have a start odometer reading, end odometer reading, and fuel used.',
+						'exec':lambda: str(MPGLogger())
+					},
+	f'{uuid1()}':{
+						'cmds':['fpl','fuel price log','fuel log','gas prices','gas'],
+						'desc':f'log gas prices for trip planning',
+						'exec':lambda: str(GasLogger())
+					},
 	f'{uuid1()}':{
 						'cmds':['value from total mass','vftm'],
 						'desc':f'give an estimated total value for mass of currency ((1/unitMass)*ValueOfUnit)*TotalMassOfUnitToBeCounted',
@@ -30,7 +50,7 @@ preloader={
 	f'{uuid1()}':{
 						'cmds':['temp logger','temp log','tmplg'],
 						'desc':f'log a temperature',
-						'exec':Templogger
+						'exec':lambda: str(Templogger())
 					},
 	f'{uuid1()}':{
 						'cmds':['mulefraud','mule fraud','mule-fraud','tax fraud mulisha','tax fraud 11.8.2025','consumer fraud 11.8.2025'],
